#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-3NzDwCMzmJm9j960eIXtky
key:                  dhall-1.42.3-3NzDwCMzmJm9j960eIXtky
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  d092c9f9480a364b096ce9a138f3d162
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-3NzDwCMzmJm9j960eIXtky
depends:
    Diff-0.5-l6wPSfM0H84LgXgk88fFs aeson-2.2.1.0-HnfSu9AKfZzFhPBHWndcTt
    aeson-pretty-0.8.10-JaM59VeCrhU14lszEheWH4
    ansi-terminal-1.1-835k7LpO3VY5VImF1e2otx
    atomic-write-0.2.1.1-7nvRc4ZfVPqFxzk3pl0YXn base-4.18.2.1
    base16-bytestring-1.0.2.0-5SHxunXITO93fpwKLO6qwm
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GnOJAdyFoN9CEG6vEkYfx
    cborg-0.2.10.0-9p89dzMZFyC9FxH1KC8a3p
    cborg-json-0.2.6.0-FHyZtK0xxGK8Hanjsl1Dwo containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-IjDHFHZpKc7CFRuTAzU1JX
    data-fix-0.3.4-LWRle9iT0RpLD04TQnVu5j deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-8K59yKloaWt4mC9EK6U1us exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-AWxPP5EHcqAAfHq3JJfEx0
    hashable-1.4.7.0-IX17aYqP3drGri7tV4VHWj haskeline-0.8.2.1
    http-client-0.7.19-EVmHbVjkohhiJgPWVdNtw
    http-client-tls-0.3.6.4-GDksyJ5Nzq117qoaBKOr4F
    http-types-0.12.4-LRx8vzb7Bf1JlNkRF4x5ME
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-EBcLwr2gq2KHbiXo0jdWHY
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-5BhbH0Z6X1TIpLC2mwzRGv
    optparse-applicative-0.18.1.0-AH2zpzau3pe5hR7FNqrvmA
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-GG54dwPEXaS8gqV9vEmgts
    pretty-simple-4.1.4.0-K4lCe3BdjGbLyQMinUGB3D
    prettyprinter-1.7.1-5fp5g306PJQFs6XChHaX6T
    prettyprinter-ansi-terminal-1.1.3-AkSdvHJnJ424lP1on6ghw6
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-D8ZBvkxtMlXDeJRB9bEi4U
    serialise-0.2.6.1-11IjmAbW8bEJKm0sVHnBXQ template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-CubcHjKTo5iJTX4CvlWRJj
    text-short-0.1.6-3z37ckIeLgnCm7JxMMOEde
    th-lift-instances-0.1.20-5sjkzlXEeEF1wBGgYt8MVZ time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-9TtdAe1unL5oc4IhnK1KL
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM
    vector-0.13.2.0-5YxFBFTVtOB5p4D1EBw8Kb

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

